@@ -58,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.095
+Version 0.096
 
 =cut
 
-our $VERSION = '0.095';
+our $VERSION = '0.096';
 
 
 =head2 Development status
@@ -504,6 +504,7 @@ Assuming the previous steps were completed correctly, all the tests should
 complete without errors.
 
 =item * B<Start the server>
+
 The last step is to start the Dochazka REST service. Maybe, in the future,
 this will be possible using a command like C<systemctl start dochazka.service>.
 Right now, though, an executable is run, as root, manually from the bash prompt:
@@ -527,14 +528,6 @@ need to set those up, as well.
 
 
 
-=head1 STARTING THE SERVER
-
-Once L<App::Dochazka::REST> is installed, the server is started like this:
-
-    $ dochazka-rest
-
-
-
 =head1 AUTHENTICATION
 
 Since employees do not access the database directly, but only via the
