@@ -43,6 +43,7 @@ use DBI;
 use JSON;
 use Try::Tiny;
 
+use parent 'App::Dochazka::REST::dbh';
 
 
 =head1 NAME
@@ -54,11 +55,11 @@ App::Dochazka::REST::Model::Schedintvls - object class for "scratch schedules"
 
 =head1 VERSION
 
-Version 0.095
+Version 0.096
 
 =cut
 
-our $VERSION = '0.095';
+our $VERSION = '0.096';
 
 
 
@@ -127,11 +128,11 @@ which is, in turn, called automatically by 'spawn')
 
 sub populate {
     my ( $self ) = @_;
-    #if ( ! $self->{dbh}->ping ) {
+    #if ( ! $self->dbh->ping ) {
     #    $CELL->status_crit( 'DOCHAZKA_DB_NOT_ALIVE' );
     #    croak();
     #} 
-    my $ss = _next_scratch_sid( $self->{dbh} );
+    my $ss = _next_scratch_sid( $self->dbh );
     $log->debug( "Got next scratch SID: $ss" );
     $self->{scratch_sid} = $ss;
     return;
@@ -188,7 +189,7 @@ sub load {
     my ( $self ) = @_;
 
     # prepare and execute statement
-    my $dbh = $self->{dbh};
+    my $dbh = $self->dbh;
     my $sth = $dbh->prepare( $site->SQL_SCHEDINTVLS_SELECT );
     $sth->execute( $self->{scratch_sid} );
 
@@ -219,7 +220,7 @@ Field values are taken from the object. Returns a status object.
 
 sub insert {
     my ( $self ) = @_;
-    my $dbh = $self->{dbh};
+    my $dbh = $self->dbh;
     my $status;
 
     # the insert operation needs to take place within a transaction,
@@ -270,7 +271,7 @@ Returns a status object.
 
 sub delete {
     my ( $self ) = @_;
-    my $dbh = $self->{dbh};
+    my $dbh = $self->dbh;
     my $status;
 
     $dbh->{AutoCommit} = 0;
@@ -292,7 +293,7 @@ sub delete {
         }
     } catch {
         $dbh->rollback;
-        #$log->err( 'DBI ERR' . $self->{dbh}->errstr );
+        #$log->err( 'DBI ERR' . $dbh->errstr );
         $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ] );
     };
 
